%This is a Matlab script developed by Konstantinos Glynis
%based on the analysis of (https://www.itia.ntua.gr/el/docinfo/2079/)
%K. Glynis, T. Iliopoulou, P. Dimitriadis, and D. Koutsoyiannis, Stochastic investigation 
%of daily air temperature extremes from a global ground station network

clc; clear all; close all;

minimum = 30; %minimum record length
maximum = inf; %maximum record length
limit1 = 1935; %latest year of record start

tail = 2; %Lower tail

tic;
[~,stations] = xlsread('Data_List_Tavg.xlsx');
load('numyears_Tavg.mat');
size = 245; %number of stations which entered service before 1935

start_year = 1881;
end_year = 1988;
Kp_alpha = NaN(size,end_year-start_year+1);
Kp_beta = NaN(size,end_year-start_year+1);
Kp_gamma = NaN(size,end_year-start_year+1);
Kp_delta = NaN(size,end_year-start_year+1);

temp1 = 0;
all = 106283;
for number = 1:all;
   filename = strcat('NOAA_GHCND_TAVG/',char(stations(number)));
   load(filename);
   if number == 43375;
       S = S(2273:end,:);
   end
   n=numel(S(:,4));
   if n > 0;
       years = S(n,1)-S(1,1)+1;
       S = new_cleaning(Q,S);
        if S(1,1) <= limit1;
           if and(and(years >= minimum,years <= maximum),and(n/365.25 >= minimum,n/365.25 <= maximum));
               temp1 = temp1+1;
               for i = 1:12;
                   pos = ismember(S(:,2),i);
                   m(i,1) = nanmean(S(pos,4)); %monthly average
                   m(i,2) = nanvar(S(pos,4)); %monthly variance
                   S(pos,4) = (S(pos,4)-m(i,1))/sqrt(m(i,2)); %monthly standardization
               end
               clear point1; clear point2; clear x; clear y;
               for j = 1:years-29 %number of distinct 30-year periods
                   point1 = min(round(1+(j-1)*365.25),n-10957); %start point of 30-year period
                   point2 = min(point1+10957,n); %end point of 30-year period
                   pos = S(point1,1)-(start_year-1);
                   [Kp_alpha(temp1,pos),Kp_beta(temp1,pos),Kp_gamma(temp1,pos),Kp_delta(temp1,pos)] = K_calc_2(S(point1:point2,:),tail);
               end
           end
        end
   end
end

y_alpha = new_organize(Kp_alpha,end_year-start_year+1);
y_beta = new_organize(Kp_beta,end_year-start_year+1);
y_gamma = new_organize(Kp_gamma,end_year-start_year+1);
y_delta = new_organize(Kp_delta,end_year-start_year+1);

years = [start_year:1:end_year];
figure(1)
hold on; grid on;
plot(years,y_alpha(1,:));
plot(years,y_alpha(2,:));
plot(years,y_alpha(3,:));
xlim([1881 1988]);
title('T_1_ = 4.95 years');
xlabel('Start of 30 year period');
legend('75th percentile','50th percentile','25th percentile')
hold off

figure(2)
hold on; grid on;
plot(years,y_beta(1,:));
plot(years,y_beta(2,:));
plot(years,y_beta(3,:));
xlim([1881 1988]);
title('T_2_ = 16.49 years');
xlabel('Start of 30 year period');
legend('75th percentile','50th percentile','25th percentile')
hold off

figure(3)
hold on; grid on;
plot(years,y_gamma(1,:));
plot(years,y_gamma(2,:));
plot(years,y_gamma(3,:));
xlim([1881 1988]);
title('T_3_ = 32.98 years');
xlabel('Start of 30 year period');
legend('75th percentile','50th percentile','25th percentile')
hold off

figure(4)
hold on; grid on;
plot(years,y_delta(1,:));
plot(years,y_delta(2,:));
plot(years,y_delta(3,:));
xlim([1881 1988]);
title('T_4_ = 49.47 years');
xlabel('Start of 30 year period');
legend('75th percentile','50th percentile','25th percentile')
hold off

toc;